Errors
======

.. include:: ./test-setup.rst


InvalidTypeError
----------------

.. autoclass:: owlmixin.errors.InvalidTypeError
    :members:
    :inherited-members:


UnknownPropertiesError
----------------------

.. autoclass:: owlmixin.errors.UnknownPropertiesError
    :members:
    :inherited-members:


RequiredError
-------------

.. autoclass:: owlmixin.errors.RequiredError
    :members:
    :inherited-members:
